@@ -2,10 +2,18 @@ from ctypes import *
 import os
 import base64
 
+import platform
+
+lib_path = None
+if platform.system().lower() == 'linux':
+    lib_path = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)),
+        'so/libcim.so')
+else:
+    lib_path = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)),
+        'dll/cim.dll')
 
-lib_path = os.path.join(
-    os.path.dirname(os.path.realpath(__file__)),
-    'so/libcim.so')
 ccompressor = cdll.LoadLibrary(lib_path)
 
 ccompressor.c_compress_image.argtypes = [
@@ -45,9 +53,10 @@ class Compressor(object):
     def decompress(compressed: bytes, buffer_size=10*1024*1024):
         decompressed_bytes = create_string_buffer(b'0', size=buffer_size)
         decompressed_len = c_ulong(buffer_size)
+        raw_compressed = base64.decodebytes(compressed)
         code = ccompressor.c_decompress_image(
-            base64.decodebytes(compressed),
-            len(compressed),
+            raw_compressed,
+            len(raw_compressed),
             decompressed_bytes,
             byref(decompressed_len)
         )
